# Easy Data Explorer
Python library to do common data exploring tasks 

## To build

Generate dist
+ `py -m pip install --upgrade build`
+ `py -m build`

Upload dist
+ `py -m pip install --upgrade twine`
+ `py -m twine upload  dist/*`

Install library
+ `py -m pip install easy-data-explorer-amandeepfj`

Upgrade to latest version library
+ `py -m pip install easy-data-explorer-amandeepfj -U`